@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: buildouthttp.py 112777 2010-05-27 12:09:23Z dobe $
+$Id: buildouthttp.py 112794 2010-05-28 11:41:12Z dobe $
 """
 
 import urllib2
@@ -178,7 +178,7 @@ class URLOpener(download.URLOpener):
         self.creds = {}
         for realm, uris, user, password in creds:
             parts = urlparse.urlparse(uris)
-            self.creds[(parts.netloc, realm)] = (user, password)
+            self.creds[(parts[1], realm)] = (user, password)
         download.URLOpener.__init__(self)
 
     def prompt_user_passwd(self, host, realm):
